@@ -122,13 +122,13 @@ class MainLog(BaseLog):
                             transaction_id = request_content.get('id')
                         else:
                             transaction_id = str(uuid.uuid1()).replace("-", "")
-                        request_content = json.dumps(request_content)
+                        request_content = json.dumps(request_content, ensure_ascii=False)
                         request_length = len(request_content)  # request正文长度
                         # 接口后置流水日志处理
                         str_ret = ret_to_str(ret)
                         if str_ret:
                             str_ret = check_resp_items(str_ret)
-                        response_content = json.dumps(str_ret)
+                        response_content = json.dumps(str_ret, ensure_ascii=False)
                         response_length = len(response_content)  # response正文长度
                         log_head_length = 80
                         flow = log_head_length + request_length + response_length
